@@ -27,6 +27,7 @@
 #include "fontinfo.h"
 #include "generator.h"
 
+class QUndoStack;
 class QEventLoop;
 class QTimer;
 class KTemporaryFile;
@@ -63,6 +64,21 @@ namespace Okular {
 
 class FontExtractionThread;
 
+struct DoContinueDirectionMatchSearchStruct
+{
+    bool forward;
+    QSet< int > *pagesToNotify;
+    RegularAreaRect *match;
+    int currentPage;
+    int searchID;
+    QString text;
+    Qt::CaseSensitivity caseSensitivity;
+    bool moveViewport;
+    QColor color;
+    bool noDialogs;
+    int pagesDone;
+};
+
 class DocumentPrivate
 {
     public:
@@ -94,11 +110,12 @@ class DocumentPrivate
 
         // private methods
         QString pagesSizeString() const;
+        QString namePaperSize(double inchesWidth, double inchesHeight) const;
         QString localizedSize(const QSizeF &size) const;
         qulonglong calculateMemoryToFree();
         void cleanupPixmapMemory();
         void cleanupPixmapMemory( qulonglong memoryToFree );
-        AllocatedPixmap * searchLowestPriorityUnloadablePixmap( bool thenRemoveIt = false );
+        AllocatedPixmap * searchLowestPriorityPixmap( bool unloadableOnly = false, bool thenRemoveIt = false, DocumentObserver *observer = 0 /* any */ );
         void calculateMaxTextPages();
         qulonglong getTotalMemory();
         qulonglong getFreeMemory( qulonglong *freeSwap = 0 );
@@ -125,18 +142,23 @@ class DocumentPrivate
         bool canRemoveExternalAnnotations() const;
         void warnLimitedAnnotSupport();
 
+        // Methods that implement functionality needed by undo commands
+        void performAddPageAnnotation( int page, Annotation *annotation );
+        void performRemovePageAnnotation( int page, Annotation * annotation );
+        void performModifyPageAnnotation( int page, Annotation * annotation, bool appearanceChanged );
+        void performSetAnnotationContents( const QString & newContents, Annotation *annot, int pageNumber );
+
         // private slots
         void saveDocumentInfo() const;
         void slotTimedMemoryCheck();
-        void sendGeneratorRequest();
+        void sendGeneratorPixmapRequest();
         void rotationFinished( int page, Okular::Page *okularPage );
         void fontReadingProgress( int page );
         void fontReadingGotFont( const Okular::FontInfo& font );
         void slotGeneratorConfigChanged( const QString& );
         void refreshPixmaps( int );
         void _o_configChanged();
-        void doContinueNextMatchSearch(void *pagesToNotifySet, void * match, int currentPage, int searchID, const QString & text, int caseSensitivity, bool moveViewport, const QColor & color, bool noDialogs, int donePages);
-        void doContinuePrevMatchSearch(void *pagesToNotifySet, void * theMatch, int currentPage, int searchID, const QString & text, int theCaseSensitivity, bool moveViewport, const QColor & color, bool noDialogs, int donePages);
+        void doContinueDirectionMatchSearch(void *doContinueDirectionMatchSearchStruct);
         void doContinueAllDocumentSearch(void *pagesToNotifySet, void *pageMatchesMap, int currentPage, int searchID, const QString & text, int caseSensitivity, const QColor & color);
         void doContinueGooglesDocumentSearch(void *pagesToNotifySet, void *pageMatchesMap, int currentPage, int searchID, const QStringList & words, int caseSensitivity, const QColor & color, bool matchAll);
 
@@ -185,7 +207,10 @@ class DocumentPrivate
         QString m_nextDocumentDestination;
 
         // observers / requests / allocator stuff
-        QMap< int, DocumentObserver * > m_observers;
+        QSet< DocumentObserver * > m_observers;
+        // FIXME This is a hack, we need to support
+        // multiple tiled observers, but for the moment we only support one
+        DocumentObserver *m_tiledObserver;
         QLinkedList< PixmapRequest * > m_pixmapRequestsStack;
         QLinkedList< PixmapRequest * > m_executingPixmapRequests;
         QMutex m_pixmapRequestsMutex;
@@ -243,8 +268,13 @@ class DocumentPrivate
         bool m_annotationsNeedSaveAs;
         bool m_annotationBeingMoved; // is an annotation currently being moved?
         bool m_showWarningLimitedAnnotSupport;
+
+        QUndoStack *m_undoStack;
+        QDomNode m_prevPropsOfAnnotBeingModified;
 };
 
 }
 
 #endif
+
+/* kate: replace-tabs on; indent-width 4; */
