@@ -50,8 +50,6 @@
 
 #include <config-okular-poppler.h>
 
-#include <algorithm>
-
 #ifdef HAVE_POPPLER_0_20
 #  include <poppler-media.h>
 #endif
@@ -1479,9 +1477,6 @@ void PDFGenerator::addAnnotations( Poppler::Page * popplerPage, Okular::Page * p
 {
     QList<Poppler::Annotation*> popplerAnnotations = popplerPage->annotations();
 
-    // Reverse the list so that the z-order of Poppler/PDF matches the z-order used by Okular
-    std::reverse(popplerAnnotations.begin(), popplerAnnotations.end());
-
     foreach(Poppler::Annotation *a, popplerAnnotations)
     {
         bool doDelete = true;
